# coding=utf-8

from earthdiagnostics.diagnostic import Diagnostic
from earthdiagnostics.utils import TempFile
from earthdiagnostics import cdftools


class Transport(Diagnostic):
    """
    Cuts a meridional or zonal section

    :original author: Virginie Guemas <virginie.guemas@bsc.es>
    :contributor: Javier Vegas-Regidor<javier.vegas@bsc.es>

    :created: September 2012
    :last modified: June 2016

    :param data_manager: data management object
    :type data_manager: DataManager
    :param startdate: startdate
    :type startdate: str
    :param member: member number
    :type member: int
    :param chunk: chunk's number
    :type chunk: int
    """

    alias = 'transport'
    "Diagnostic alias for the configuration file"

    def __init__(self, data_manager, startdate, member, chunk):
        Diagnostic.__init__(self, data_manager)
        self.config = 'ORCA1-L75'
        self.startdate = startdate
        self.member = member
        self.chunk = chunk

    def __eq__(self, other):
        return self.startdate == other.startdate and self.member == other.member and self.chunk == other.chunk

    def __str__(self):
        return 'Rotate variables Startdate: {0} Member: {1} Chunk: {2}'.format(self.startdate, self.member, self.chunk)

    @classmethod
    def generate_jobs(cls, diags, options):
        """
        Creates a job for each chunk to compute the diagnostic

        :param diags: Diagnostics manager class
        :type diags: Diags
        :param options: variable, zonal, value, domain=ocean
        :type options: list[str]
        :return:
        """
        # options_available = (DiagnosticVariableOption('variableu'),
        #                      DiagnosticVariableOption('variablev'),
        #                      DiagnosticDomainOption('domain', ModelingRealms.ocean),
        #                      DiagnosticOption('executable',
        #                                       '/home/Earth/jvegas/pyCharm/cfutools/interpolation/rotateUVorca'))
        # options = cls.process_options(options, options_available)

        job_list = list()
        for startdate, member, chunk in diags.config.experiment.get_chunk_list():
            job_list.append(Transport(diags.data_manager, startdate, member, chunk))
        return job_list

    def compute(self):
        """
        Runs the diagnostic
        """
        # ufile = self.data_manager.get_file(ModelingRealms.ocean, 'tauuo', self.startdate, self.member, self.chunk)
        # vfile = self.data_manager.get_file(ModelingRealms.ocean, 'tauuv', self.startdate, self.member, self.chunk)

        temp = TempFile.get()
        cdftools.run('cdfvT', self.config, output=temp)






